@@ -12,9 +12,9 @@ import os
 import re
 import subprocess
 import sys
-from collections import namedtuple
 
 from . import _common
+from . import _ntuples as ntp
 from . import _psposix
 from . import _psutil_aix as cext
 from ._common import NIC_DUPLEX_FULL
@@ -78,21 +78,6 @@ proc_info_map = dict(
 )
 
 
-# =====================================================================
-# --- named tuples
-# =====================================================================
-
-
-# psutil.Process.memory_info()
-pmem = namedtuple('pmem', ['rss', 'vms'])
-# psutil.Process.memory_full_info()
-pfullmem = pmem
-# psutil.Process.cpu_times()
-scputimes = namedtuple('scputimes', ['user', 'system', 'idle', 'iowait'])
-# psutil.virtual_memory()
-svmem = namedtuple('svmem', ['total', 'available', 'percent', 'used', 'free'])
-
-
 # =====================================================================
 # --- memory
 # =====================================================================
@@ -101,7 +86,7 @@ svmem = namedtuple('svmem', ['total', 'available', 'percent', 'used', 'free'])
 def virtual_memory():
     total, avail, free, _pinned, inuse = cext.virtual_mem()
     percent = usage_percent((total - avail), total, round_=1)
-    return svmem(total, avail, percent, inuse, free)
+    return ntp.svmem(total, avail, percent, inuse, free)
 
 
 def swap_memory():
@@ -109,7 +94,7 @@ def swap_memory():
     total, free, sin, sout = cext.swap_mem()
     used = total - free
     percent = usage_percent(used, total, round_=1)
-    return _common.sswap(total, used, free, percent, sin, sout)
+    return ntp.sswap(total, used, free, percent, sin, sout)
 
 
 # =====================================================================
@@ -120,13 +105,13 @@ def swap_memory():
 def cpu_times():
     """Return system-wide CPU times as a named tuple."""
     ret = cext.per_cpu_times()
-    return scputimes(*[sum(x) for x in zip(*ret)])
+    return ntp.scputimes(*[sum(x) for x in zip(*ret)])
 
 
 def per_cpu_times():
     """Return system per-CPU times as a list of named tuples."""
     ret = cext.per_cpu_times()
-    return [scputimes(*x) for x in ret]
+    return [ntp.scputimes(*x) for x in ret]
 
 
 def cpu_count_logical():
@@ -153,9 +138,7 @@ def cpu_count_cores():
 def cpu_stats():
     """Return various CPU stats as a named tuple."""
     ctx_switches, interrupts, soft_interrupts, syscalls = cext.cpu_stats()
-    return _common.scpustats(
-        ctx_switches, interrupts, soft_interrupts, syscalls
-    )
+    return ntp.scpustats(ctx_switches, interrupts, soft_interrupts, syscalls)
 
 
 # =====================================================================
@@ -183,7 +166,7 @@ def disk_partitions(all=False):
             # filter by filesystem having a total size > 0.
             if not disk_usage(mountpoint).total:
                 continue
-        ntuple = _common.sdiskpart(device, mountpoint, fstype, opts)
+        ntuple = ntp.sdiskpart(device, mountpoint, fstype, opts)
         retlist.append(ntuple)
     return retlist
 
@@ -260,7 +243,7 @@ def net_if_stats():
         output_flags = ','.join(flags)
         isup = 'running' in flags
         duplex = duplex_map.get(duplex, NIC_DUPLEX_UNKNOWN)
-        ret[name] = _common.snicstats(isup, duplex, speed, mtu, output_flags)
+        ret[name] = ntp.snicstats(isup, duplex, speed, mtu, output_flags)
     return ret
 
 
@@ -288,7 +271,7 @@ def users():
             continue
         if hostname in localhost:
             hostname = 'localhost'
-        nt = _common.suser(user, tty, hostname, tstamp, pid)
+        nt = ntp.suser(user, tty, hostname, tstamp, pid)
         retlist.append(nt)
     return retlist
 
@@ -420,7 +403,7 @@ class Process:
             rawlist = cext.proc_threads(self.pid)
             retlist = []
             for thread_id, utime, stime in rawlist:
-                ntuple = _common.pthread(thread_id, utime, stime)
+                ntuple = ntp.pthread(thread_id, utime, stime)
                 retlist.append(ntuple)
             # The underlying C implementation retrieves all OS threads
             # and filters them by PID.  At this point we can't tell whether
@@ -461,17 +444,17 @@ class Process:
     @wrap_exceptions
     def uids(self):
         real, effective, saved, _, _, _ = self._proc_cred()
-        return _common.puids(real, effective, saved)
+        return ntp.puids(real, effective, saved)
 
     @wrap_exceptions
     def gids(self):
         _, _, _, real, effective, saved = self._proc_cred()
-        return _common.puids(real, effective, saved)
+        return ntp.puids(real, effective, saved)
 
     @wrap_exceptions
     def cpu_times(self):
         t = cext.proc_cpu_times(self.pid, self._procfs_path)
-        return _common.pcputimes(*t)
+        return ntp.pcputimes(*t)
 
     @wrap_exceptions
     def terminal(self):
@@ -499,7 +482,7 @@ class Process:
         ret = self._proc_basic_info()
         rss = ret[proc_info_map['rss']] * 1024
         vms = ret[proc_info_map['vms']] * 1024
-        return pmem(rss, vms)
+        return ntp.pmem(rss, vms)
 
     memory_full_info = memory_info
 
@@ -531,7 +514,7 @@ class Process:
                 path = path[1:]
             if path.lower() == "cannot be retrieved":
                 continue
-            retlist.append(_common.popenfile(path, int(fd)))
+            retlist.append(ntp.popenfile(path, int(fd)))
         return retlist
 
     @wrap_exceptions
@@ -542,11 +525,11 @@ class Process:
 
     @wrap_exceptions
     def num_ctx_switches(self):
-        return _common.pctxsw(*cext.proc_num_ctx_switches(self.pid))
+        return ntp.pctxsw(*cext.proc_num_ctx_switches(self.pid))
 
     @wrap_exceptions
     def wait(self, timeout=None):
-        return _psposix.wait_pid(self.pid, timeout, self._name)
+        return _psposix.wait_pid(self.pid, timeout)
 
     if HAS_PROC_IO_COUNTERS:
 
@@ -560,4 +543,4 @@ class Process:
                 if not pid_exists(self.pid):
                     raise NoSuchProcess(self.pid, self._name) from err
                 raise
-            return _common.pio(rc, wc, rb, wb)
+            return ntp.pio(rc, wc, rb, wb)
